@@ -11,8 +11,8 @@ class Database_Handler:
     def search_records(self, columns, keywords):
         return self.handler.search_for_records(columns, keywords)
     
-    def insert_record(self, keywords):
-        return self.handler.insert_row(keywords)
+    def insert_record(self, **keywords):
+        return self.handler.insert_row(**keywords)
     
     def update_record(self, keywords):
         return self.handler.update_record(keywords)
