@@ -67,7 +67,7 @@ class Postgres_Handler:
         table_name_key = 'table_name'
         
         #Start of query string
-        query = f"SELECT * FROM %(table_name)s"
+        query = f'SELECT * FROM "{keywords[table_name_key]}'
         
         if table_name_key not in keywords:
             assert("Error: table_name required as argument")
@@ -77,9 +77,9 @@ class Postgres_Handler:
         start_date_key = "SearchStartDate"
         end_date_key = "SearchEndDate"
 
-        if len(self.keywords) != 0:
+        if len(keywords) != 0:
             #Iterates through the keywords to build search string
-            for key, item in self.keywords.items():
+            for key, item in keywords.items():
                 if key == table_name_key: continue
                 
                 if where_string != '':
